# PyLink Documentation

This folder contains general documentation for PyLink IRC services.

## Contents

- [PyLink FAQ (Frequently Asked Questions)](faq.md)
- [PyLink Relay Tutorial & Oper Guide](pylink-opers.md)
- [Automode & Exttargets Guide](automode.md)
- [Developer documentation](technical/)

There is also a (WIP) Doxygen-powered API reference at https://pylink.github.io/
